==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>CadToolBar</name>
    <message>
        <location filename="../CadToolBar.js" line="+49"/>
        <source>Widgets</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Własne widżety
Zastępcze widżety</translatorcomment>
        <translation type="unfinished">Widżety</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">CAD Toolbar</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Toggle Title Bar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przełącz Nagłówek</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Rozmiar ikon:</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Pixel</source>
        <translatorcomment>--google--
Przenośna pixmapa
Format X Pixel Map
%1 (%2x%3 piksli)</translatorcomment>
        <translation type="unfinished">Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translatorcomment>--google--
Minimalny odstęp siatki (piksele):
Minimalny odstęp siatki (piksele)</translatorcomment>
        <translation type="unfinished">px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kolumny:
Kolumn:</translatorcomment>
        <translation type="unfinished">Kolumn:</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+76"/>
        <source>Back</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Back
Powrót do poprzedniego menu</translatorcomment>
        <translation type="unfinished">Back</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>CadToolBar</name>
    <message>
        <location filename="../CadToolBar.js" line="+51"/>
        <source>Widgets</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Własne widżety
Zastępcze widżety</translatorcomment>
        <translation type="unfinished">Widżety</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">CAD Toolbar</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Title Bar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Przełącz Nagłówek</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Rozmiar ikon:</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Pixel</source>
        <translatorcomment>--google--
Przenośna pixmapa
Format X Pixel Map
%1 (%2x%3 piksli)</translatorcomment>
        <translation type="unfinished">Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translatorcomment>--google--
Minimalny odstęp siatki (piksele):
Minimalny odstęp siatki (piksele)</translatorcomment>
        <translation type="unfinished">px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kolumny:
Kolumn:</translatorcomment>
        <translation type="unfinished">Kolumn:</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+107"/>
        <source>Back</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Back
Powrót do poprzedniego menu</translatorcomment>
        <translation type="unfinished">Back</translation>
    </message>
</context>
</TS>
